package osgi.cache;

import java.io.Serializable;
import java.net.URL;
import java.rmi.RMISecurityManager;

import net.sf.ehcache.Cache;
import net.sf.ehcache.CacheManager;
import net.sf.ehcache.Element;

import org.slf4j.LoggerFactory;

public class ContentCache implements Serializable{

	private static final long serialVersionUID = 4059934572946058400L;
	private static final transient org.slf4j.Logger log = LoggerFactory.getLogger(ContentCache.class);
	private static Cache cache = null;

	public static Cache getCache() {
		
		if (cache == null) {
			URL url = ContentCache.class.getResource("/ehcache.xml");
			log.info("valor de url: "+ url.toString());
			cache = CacheManager.create(url).getCache("cacheDistribuida");
		}
		
		log.debug("[FileContentCache] Devolviendo cache distribuida: " + cache.getName());
		log.debug("[FileContentCache] Cache en cluster" + cache.getCacheConfiguration().isTerracottaClustered());
		return cache;
	}
	
	public static byte[] getFileContent(String id) {
		
		log.debug("[FileContentCache] Devolviendo contenido del key: " + id);
		Element element = getCache().get(id);
		if (element != null) {
			
			log.debug("[FileContentCache] El contenido que se ha obtenido: " + new String((byte[])element.getObjectValue()));
			return (byte[]) element.getObjectValue();
		} else {
			log.error("[FileContentCache] El contenido obtenido es nulo");
			return null;
		}
	}
	
	public static boolean existFileContent(String id) {
		
		log.debug("[FileContentCache] Comprobando si exisiste la entrada con key: " + id);
		boolean exist = getCache().isKeyInCache(id);
		
		log.debug("[FileContentCache] Existe entrada?: " + exist);
		return exist;
	}

	public static void setFileContent(String id, byte[] fileContent) {
		
		log.debug("[FileContentCache] Asignando contenido al key id: " + id);
		if (id == null)
			return;
		getCache().put(new Element(id, fileContent));
	}
	
	
	public static void unsetFileContent(String id) {
		
		log.debug("[FileContentCache] Liberando contenido del key id: " + id);
		if (id == null)
			return;
		getCache().remove(id);
	}

}
